==> blender-2.45.tar.bz2: blender-2.45/source/gameengine/Rasterizer/RAS_IRenderTools.cpp <==
/**
 * $Id: RAS_IRenderTools.cpp 2169 2004-03-22 22:02:18Z jesterking $
 * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. The Blender
 * Foundation also sells licenses for use in proprietary software under
 * the Blender License.  See http://www.blender.org/BL/ for information
 * about this.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL/BL DUAL LICENSE BLOCK *****
 */

#include "RAS_IRenderTools.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

void RAS_IRenderTools::SetViewMat(const MT_Transform& trans)
{
	trans.getValue(m_viewmat);
}
	


void RAS_IRenderTools::SetClientObject(void* obj)
{
	if (m_clientobject != obj)
	{
		m_clientobject = obj;
		m_modified = true;
	}
}



void RAS_IRenderTools::SetAuxilaryClientInfo(void* inf)
{
	m_auxilaryClientInfo = inf;
}



void RAS_IRenderTools::AddLight(struct RAS_LightObject* lightobject)
{
	m_lights.push_back(lightobject);
}



void RAS_IRenderTools::RemoveLight(struct RAS_LightObject* lightobject)
{
	std::vector<struct	RAS_LightObject*>::iterator lit = 
		std::find(m_lights.begin(),m_lights.end(),lightobject);

	if (!(lit==m_lights.end()))
		m_lights.erase(lit);

}

==> blender_2.66.orig.tar.bz2: blender-2.66/source/gameengine/Rasterizer/RAS_IRenderTools.cpp <==
/*
 * ***** BEGIN GPL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL LICENSE BLOCK *****
 */

/** \file gameengine/Rasterizer/RAS_IRenderTools.cpp
 *  \ingroup bgerast
 */


#include "RAS_IRenderTools.h"

void RAS_IRenderTools::SetClientObject(RAS_IRasterizer* rasty, void *obj)
{
	if (m_clientobject != obj)
		m_clientobject = obj;
}

void RAS_IRenderTools::SetAuxilaryClientInfo(void* inf)
{
	m_auxilaryClientInfo = inf;
}

void RAS_IRenderTools::AddLight(struct RAS_LightObject* lightobject)
{
	m_lights.push_back(lightobject);
}

void RAS_IRenderTools::RemoveLight(struct RAS_LightObject* lightobject)
{
	std::vector<struct	RAS_LightObject*>::iterator lit = 
		std::find(m_lights.begin(),m_lights.end(),lightobject);

	if (!(lit==m_lights.end()))
		m_lights.erase(lit);
}
